/// <reference types="express-serve-static-core" />
import { Request } from 'express';
import { ClientOptions, ItemBucketMetadata } from 'minio';
import multer from 'multer';
import sharp from 'sharp';
export declare type TransformType = {
    id: string;
    sharp: (req: Request, file: Express.Multer.File, transform: TransformType) => sharp.Sharp;
    key?: (req: Request, file: Express.Multer.File, transform: TransformType) => string;
    objectMeta?: (req: Request, file: Express.Multer.File, transform: TransformType) => ItemBucketMetadata;
};
export declare type ExtendedMulterFileType = Partial<Express.Multer.File & {
    [prop: string]: any;
}>;
export declare type KeyCallbackType = (req: Request, file: Express.Multer.File, transform: TransformType) => string;
export declare type ObjectMetaCallbackType = (req: Request, file: Express.Multer.File, transform: TransformType) => ItemBucketMetadata;
export declare type TransformedType = {
    id: string;
    status: 'success' | 'error';
    object?: ItemBucketMetadata & {
        key: string;
    };
    meta?: sharp.Metadata;
};
export declare type HandleFileCallbackInfoType = ExtendedMulterFileType;
export declare type HandleFileCallbackType = (error?: any, info?: HandleFileCallbackInfoType) => void;
export declare type GeneratorCallbackParamsType = {
    opts: MulterMinioSharpStorageOptions;
    file: Express.Multer.File;
    transforms: TransformedType[];
};
export declare type GeneratorCallbackType = (params: GeneratorCallbackParamsType) => ExtendedMulterFileType;
export declare type MulterMinioSharpStorageOptions = {
    key?: KeyCallbackType;
    objectMeta?: ObjectMetaCallbackType;
    withSharpMeta?: boolean;
    bucket: string;
    clientOptions: ClientOptions;
    transforms: TransformType[];
    generator?: GeneratorCallbackType;
};
declare class MulterMinioSharpStorage implements multer.StorageEngine {
    private opts;
    private key?;
    private objectMeta?;
    private withSharpMeta?;
    private generator?;
    private bucket;
    private minioClient;
    private transforms;
    constructor(opts: MulterMinioSharpStorageOptions);
    _handleFile(req: Request, file: Express.Multer.File, callback: HandleFileCallbackType): void;
    _removeFile: (_req: Request, file: Express.Multer.File, callback: (error: Error | null) => void) => void;
}
export default MulterMinioSharpStorage;
